@@ -35,7 +35,7 @@ def gentle_asarray(a, dtype):
             if np.can_cast(in_dtype, out_dtype, 'equiv'):
                 return a
             else:
-                return np.asanyarray(a, dtype=out_dtype)
+                return _safe_asanyarray(a, out_dtype)
         elif in_dtype.fields is not None and out_dtype.fields is not None:
             # When a FITS file includes a pseudo-unsigned-int column, astropy will return
             # a FITS_rec with an incorrect table dtype.  The following code rebuilds
@@ -44,18 +44,8 @@ def gentle_asarray(a, dtype):
             # We can remove this once the issue is resolved in astropy:
             # https://github.com/astropy/astropy/issues/8862
             if isinstance(a, fits.fitsrec.FITS_rec):
-                new_in_dtype = []
-                updated = False
-                for field_name in in_dtype.fields:
-                    table_dtype = in_dtype[field_name]
-                    field_dtype = a.field(field_name).dtype
-                    if np.issubdtype(table_dtype, np.signedinteger) and np.issubdtype(field_dtype, np.unsignedinteger):
-                        new_in_dtype.append((field_name, field_dtype))
-                        updated = True
-                    else:
-                        new_in_dtype.append((field_name, table_dtype))
-                if updated:
-                    in_dtype = np.dtype(new_in_dtype)
+                a.dtype = rebuild_fits_rec_dtype(a)
+                in_dtype = a.dtype
 
             if in_dtype == out_dtype:
                 return a
@@ -86,10 +76,10 @@ def gentle_asarray(a, dtype):
                          type_str,
                          in_type.shape))
                 else:
-                    return np.asanyarray(a, dtype=out_dtype)
+                    return _safe_asanyarray(a, out_dtype)
             return a.view(dtype=np.dtype(new_dtype))
         else:
-            return np.asanyarray(a, dtype=out_dtype)
+            return _safe_asanyarray(a, out_dtype)
     else:
         try:
             a = np.asarray(a, dtype=out_dtype)
@@ -98,6 +88,20 @@ def gentle_asarray(a, dtype):
         return a
 
 
+def _safe_asanyarray(a, dtype):
+    if isinstance(a, fits.fitsrec.FITS_rec):
+        if any(c.bzero is not None for c in a.columns):
+            # Due to an issue in astropy, it's not safe to directly cast
+            # a FITS_rec with a pseudo-unsigned column.
+            # See https://github.com/astropy/astropy/issues/12112
+            result = np.zeros(a.shape, dtype=dtype)
+            for old_col, new_col in zip(a.dtype.names, result.dtype.names):
+                result[new_col] = a[old_col]
+            return result
+
+    return np.asanyarray(a, dtype=dtype)
+
+
 def create_history_entry(description, software=None):
     """
     Create a HistoryEntry object.
@@ -222,3 +226,16 @@ def remove_none_from_tree(tree):
             return node
 
     return treeutil.walk_and_modify(tree, _remove_none)
+
+
+def rebuild_fits_rec_dtype(fits_rec):
+    dtype = fits_rec.dtype
+    new_dtype = []
+    for field_name in dtype.fields:
+        table_dtype = dtype[field_name]
+        field_dtype = fits_rec.field(field_name).dtype
+        if np.issubdtype(table_dtype, np.signedinteger) and np.issubdtype(field_dtype, np.unsignedinteger):
+            new_dtype.append((field_name, field_dtype))
+        else:
+            new_dtype.append((field_name, table_dtype))
+    return np.dtype((np.record, new_dtype))
