@@ -93,7 +93,8 @@ def test_table_array_shape_ndim(filename, tmp_path):
     with TableModel() as x:
         x.table = [
             (
-                42,
+                -42,
+                42000,
                 37.5,
                 'STRING',
                 [[37.5, 38.0], [39.0, 40.0], [41.0, 42.0]],
@@ -102,6 +103,7 @@ def test_table_array_shape_ndim(filename, tmp_path):
         ]
         assert x.table.dtype == [
             ('int16_column', '=i2'),
+            ('uint16_column', '=u2'),
             ('float32_column', '=f4'),
             ('ascii_column', 'S64'),
             ('float32_column_with_shape', '=f4', (3, 2)),
@@ -111,19 +113,25 @@ def test_table_array_shape_ndim(filename, tmp_path):
         x.save(file_path)
 
     with TableModel(file_path) as x:
-        assert x.table.dtype == [
-            ('int16_column', '=i2'),
-            ('float32_column', '=f4'),
-            ('ascii_column', 'S64'),
-            ('float32_column_with_shape', '=f4', (3, 2)),
-            ('float32_column_with_ndim', '=f4', (3, 2)),
-        ]
+        assert np.can_cast(
+            x.table.dtype,
+            [
+                ('int16_column', '=i2'),
+                ('uint16_column', '=u2'),
+                ('float32_column', '=f4'),
+                ('ascii_column', 'S64'),
+                ('float32_column_with_shape', '=f4', (3, 2)),
+                ('float32_column_with_ndim', '=f4', (3, 2)),
+            ],
+            'equiv',
+        )
 
     with TableModel() as x:
         with pytest.raises(ValueError):
             x.table = [
                 (
-                    42,
+                    -42,
+                    42000,
                     37.5,
                     'STRING',
                     # This element should fail because it's shape is (2, 2) and not (3, 2):
